@@ -10,9 +10,11 @@ __version__     = "1.0"
 
 # =============================================================================
 import numpy as np
+from collections import namedtuple
 # =============================================================================
 
 event_dtype = np.dtype([('x', np.uint16), ('y', np.uint16),
                         ('ts', np.float32), ('p', np.int8)])
 
+Sample = namedtuple('Sample', ['name', 'label', 'events'])
 # =============================================================================
\ No newline at end of file
